@@ -541,9 +541,9 @@ menu_show (IndicatorObject * io, IndicatorObjectEntry * entry,
 	if (entry == NULL) {
 		/* Close any open menus instead of opening one */
 		GList * entries = indicator_object_get_entries(io);
-		GList * entry = NULL;
-		for (entry = entries; entry != NULL; entry = g_list_next(entry)) {
-			IndicatorObjectEntry * entrydata = (IndicatorObjectEntry *)entry->data;
+		GList * iterator = NULL;
+		for (iterator = entries; iterator != NULL; iterator = g_list_next(iterator)) {
+			IndicatorObjectEntry * entrydata = (IndicatorObjectEntry *)iterator->data;
 			gtk_menu_popdown(entrydata->menu);
 		}
 		g_list_free(entries);
@@ -808,7 +808,7 @@ about_cb (GtkAction *action G_GNUC_UNUSED,
 	gtk_show_about_dialog(NULL,
 		"version", VERSION,
 		"copyright", _("Copyright \xc2\xa9 2009-2010 Canonical, Ltd.\n"
-		               "Copyright \xc2\xa9 2011-2020 MATE developers"),
+		               "Copyright \xc2\xa9 2011-2021 MATE developers"),
 #ifdef INDICATOR_APPLET_APPMENU
 		"comments", _("An applet to hold your application menus."),
 #endif
@@ -926,7 +926,6 @@ log_to_file (const gchar * domain G_GNUC_UNUSED,
 
 			if (error != NULL) {
 				g_error("Unable to make directory '%s' for log file: %s", g_get_user_cache_dir(), error->message);
-				return;
 			}
 		}
 
@@ -938,7 +937,6 @@ log_to_file (const gchar * domain G_GNUC_UNUSED,
 		                          &error); /* error */
 		if (error != NULL) {
 			g_error("Unable to replace file: %s", error->message);
-			return;
 		}
 
 		log_file = g_io_stream_get_output_stream(G_IO_STREAM(io));
@@ -965,7 +963,7 @@ applet_fill_cb (MatePanelApplet * applet, const gchar * iid G_GNUC_UNUSED,
 #endif
 
 	static const GtkActionEntry menu_actions[] = {
-		{"About", GTK_STOCK_ABOUT, N_("_About"), NULL, NULL, G_CALLBACK(about_cb)}
+		{"About", "help-about", N_("_About"), NULL, NULL, G_CALLBACK(about_cb)}
 	};
 	static const gchar *menu_xml = "<menuitem name=\"About\" action=\"About\"/>";
 
